pub struct AssistantSessionIdError {
pub text: String,
}Expand description
A session identifier that could not be parsed from its textual form.
Fields
text: StringThe text that was offered as a session id.