pub enum ActivityErrorKind {
Retryable,
Terminal,
}Expand description
Classification for an activity failure.
Variants
Retryable
The activity failure may be retried according to the activity’s retry policy.
Terminal
The activity failure is terminal and must not be retried.