Module ids

Module ids 

Strongly typed identifiers for workflows, runs, activities, timers, and schedules. Strongly typed identifiers for workflows, activities, timers, and runs.

Structs

ActivityId
Identifier for an activity scheduled within a workflow history.
PackageVersion
Canonical textual content hash identifying one loaded workflow package version.
RunId
Identifier for a concrete run of a logical workflow.
TimerId
Identifier for a timer scheduled by workflow code or by the engine.
WorkflowId
Identifier for a logical workflow.

Enums

IdError
Errors from identifier construction.