pub struct ActivityId(/* private fields */);Expand description
Identifier for an activity scheduled within a workflow history.
Implementations
Sourceimpl ActivityId
impl ActivityId
Sourcepub const fn from_sequence_position(sequence_position: u64) -> Self
pub const fn from_sequence_position(sequence_position: u64) -> Self
Derives an activity identifier from its scheduling sequence position.
Sourcepub const fn sequence_position(&self) -> u64
pub const fn sequence_position(&self) -> u64
Returns the scheduling sequence position used to derive this identifier.