Strongly typed identifiers for workflows, runs, activities, timers, and schedules. Strongly typed identifiers for workflows, activities, timers, and runs.
Structs
- Activity
Id - Identifier for an activity scheduled within a workflow history.
- Package
Version - Canonical textual content hash identifying one loaded workflow package version.
- RunId
- Identifier for a concrete run of a logical workflow.
- TimerId
- Identifier for a timer scheduled by workflow code or by the engine.
- Workflow
Id - Identifier for a logical workflow.
Enums
- IdError
- Errors from identifier construction.